=========
Changelog
=========

1.14.0 (2023-06-13)
-------------------

* Support Python 3.12.

1.13.0 (2023-01-16)
-------------------

* Note Adam Johnson is new maintainer.

* Require Black 22.1.0+.

* Add ``--rst-literal-blocks`` option, to also format text in reStructuredText literal blocks, starting with ``::``.
  Sphinx highlights these with the project’s default language, which defaults to Python.

1.12.1 (2022-01-30)
-------------------

* Fix compatibility with Black 22.1.0.

  Thanks to Jelle Zijlstra for the fix in `PR #142 <https://github.com/adamchainz/blacken-docs/pull/142>`__.

* Drop Python 3.6 support.

  Thanks to Anthony Sottile in `PR #140 <https://github.com/adamchainz/blacken-docs/pull/140>`__.

1.12.0 (2021-11-19)
-------------------

* Fix nested reStructuredText code blocks.

No changelog kept for earlier versions.
See `log on GitHub <https://github.com/adamchainz/blacken-docs/commits/main>`__ for details.
